| BBUM_expperf | R Documentation |
BBUM_expperf computes the expected performance in terms of sensitivity
and specificity values at quantiles q (raw p-values) according to
the given parameters of the BBUM distribution.
BBUM_expperf(q, lambda, a, theta, r, dtratio = Inf)
q |
Vector of quantiles. |
lambda |
Vector of BBUM parameter |
a |
Vector of BBUM parameter |
theta |
Vector of BBUM parameter |
r |
Vector of BBUM parameter |
dtratio |
If using the "two-tailed" case of BBUM correction, provide
the ratio of number of data points in the signal class over that in the
background class. Leave as |
This is primarily used for plotting in BBUM_plot(option = "confusion").
Sensitivity is the fraction of positives that are correctly called as positives.
Specificity is the fraction of negatives that are correctly called as negatives.
If the background assumption is weak, such that a small number
of bona fide hits are anticipated and relevant to the hypothesis at
hand among the data points designated "background class", the FDR could be
made to include the background class. This is akin to a two-tailed test
(despite a one-tailed assumption to begin with). This would allow the
generation of genuine FDR-corrected p values for the background class
points as well. Toggle this using the dtratio value.
A named list of two vectors of the same length as q,
under names sensitivity and specificity.
# Default
BBUM_expperf(q = c(0.001, 0.007, 0.19, 0.5, 0.99),
lambda = 0.65, a = 0.1, theta = 0.02, r = 0.07)
# "Two-tailed"
BBUM_expperf(q = c(0.001, 0.007, 0.19, 0.5, 0.99),
lambda = 0.65, a = 0.1, theta = 0.02, r = 0.07, dtratio = 1.13)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.